Class: Google::Apis::AdsenseV2::AdBlockingRecoveryTag
- Inherits:
-
Object
- Object
- Google::Apis::AdsenseV2::AdBlockingRecoveryTag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adsense_v2/classes.rb,
lib/google/apis/adsense_v2/representations.rb,
lib/google/apis/adsense_v2/representations.rb
Overview
Representation of an ad blocking recovery tag. See https://support.google.com/ adsense/answer/11575177.
Instance Attribute Summary collapse
-
#error_protection_code ⇒ String
Error protection code that can be used in conjunction with the tag.
-
#tag ⇒ String
The ad blocking recovery tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdBlockingRecoveryTag
constructor
A new instance of AdBlockingRecoveryTag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdBlockingRecoveryTag
Returns a new instance of AdBlockingRecoveryTag.
104 105 106 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_protection_code ⇒ String
Error protection code that can be used in conjunction with the tag. It'll
display a message to users if an ad blocking extension blocks their access to
your site.
Corresponds to the JSON property errorProtectionCode
95 96 97 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 95 def error_protection_code @error_protection_code end |
#tag ⇒ String
The ad blocking recovery tag. Note that the message generated by the tag can
be blocked by an ad blocking extension. If this is not your desired outcome,
then you'll need to use it in conjunction with the error protection code.
Corresponds to the JSON property tag
102 103 104 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 102 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
109 110 111 112 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 109 def update!(**args) @error_protection_code = args[:error_protection_code] if args.key?(:error_protection_code) @tag = args[:tag] if args.key?(:tag) end |