Class: Google::Apis::AdsenseV2::CustomChannel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adsense_v2/classes.rb,
lib/google/apis/adsense_v2/representations.rb,
lib/google/apis/adsense_v2/representations.rb

Overview

Representation of a custom channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomChannel

Returns a new instance of CustomChannel.



373
374
375
# File 'lib/google/apis/adsense_v2/classes.rb', line 373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Whether the custom channel is active and collecting data. See https://support. google.com/adsense/answer/10077192. Corresponds to the JSON property active

Returns:

  • (Boolean)


353
354
355
# File 'lib/google/apis/adsense_v2/classes.rb', line 353

def active
  @active
end

#display_nameString

Required. Display name of the custom channel. Corresponds to the JSON property displayName

Returns:

  • (String)


359
360
361
# File 'lib/google/apis/adsense_v2/classes.rb', line 359

def display_name
  @display_name
end

#nameString

Output only. Resource name of the custom channel. Format: accounts/account/ adclients/adclient/customchannels/customchannel Corresponds to the JSON property name

Returns:

  • (String)


365
366
367
# File 'lib/google/apis/adsense_v2/classes.rb', line 365

def name
  @name
end

#reporting_dimension_idString

Output only. Unique ID of the custom channel as used in the CUSTOM_CHANNEL_ID reporting dimension. Corresponds to the JSON property reportingDimensionId

Returns:

  • (String)


371
372
373
# File 'lib/google/apis/adsense_v2/classes.rb', line 371

def reporting_dimension_id
  @reporting_dimension_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



378
379
380
381
382
383
# File 'lib/google/apis/adsense_v2/classes.rb', line 378

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @reporting_dimension_id = args[:reporting_dimension_id] if args.key?(:reporting_dimension_id)
end