Class: Google::Apis::AdsenseV2::ListPolicyIssuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AdsenseV2::ListPolicyIssuesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adsense_v2/classes.rb,
lib/google/apis/adsense_v2/representations.rb,
lib/google/apis/adsense_v2/representations.rb
Overview
Response definition for the policy issues list rpc. Policy issues are reported only if the publisher has at least one AFC ad client in READY or GETTING_READY state. If the publisher has no such AFC ad client, the response will be an empty list.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Continuation token used to page through policy issues.
-
#policy_issues ⇒ Array<Google::Apis::AdsenseV2::PolicyIssue>
The policy issues returned in the list response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPolicyIssuesResponse
constructor
A new instance of ListPolicyIssuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPolicyIssuesResponse
Returns a new instance of ListPolicyIssuesResponse.
761 762 763 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Continuation token used to page through policy issues. To retrieve the next
page of the results, set the next request's "page_token" value to this.
Corresponds to the JSON property nextPageToken
754 755 756 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 754 def next_page_token @next_page_token end |
#policy_issues ⇒ Array<Google::Apis::AdsenseV2::PolicyIssue>
The policy issues returned in the list response.
Corresponds to the JSON property policyIssues
759 760 761 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 759 def policy_issues @policy_issues end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
766 767 768 769 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 766 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @policy_issues = args[:policy_issues] if args.key?(:policy_issues) end |