Class: Google::Apis::AdsenseV2::PolicyTopic
- Inherits:
-
Object
- Object
- Google::Apis::AdsenseV2::PolicyTopic
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adsense_v2/classes.rb,
lib/google/apis/adsense_v2/representations.rb,
lib/google/apis/adsense_v2/representations.rb
Overview
Information about a particular policy topic. A policy topic represents a single class of policy issue that can impact ad serving for your site. For example, sexual content or having ads that obscure your content. A single policy issue can have multiple policy topics for a single entity.
Instance Attribute Summary collapse
-
#must_fix ⇒ Boolean
(also: #must_fix?)
Required.
-
#topic ⇒ String
Required.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PolicyTopic
constructor
A new instance of PolicyTopic.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PolicyTopic
Returns a new instance of PolicyTopic.
1045 1046 1047 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#must_fix ⇒ Boolean Also known as: must_fix?
Required. Deprecated. Always set to false.
Corresponds to the JSON property mustFix
1029 1030 1031 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1029 def must_fix @must_fix end |
#topic ⇒ String
Required. The policy topic. For example, "sexual-content" or "ads-obscuring-
content"."
Corresponds to the JSON property topic
1036 1037 1038 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1036 def topic @topic end |
#type ⇒ String
Optional. The type of policy topic. For example, "POLICY" represents all the
policy topics that are related to the Google Publisher Policy (GPP). See https:
//support.google.com/adsense/answer/15689616.
Corresponds to the JSON property type
1043 1044 1045 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1043 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1050 1051 1052 1053 1054 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1050 def update!(**args) @must_fix = args[:must_fix] if args.key?(:must_fix) @topic = args[:topic] if args.key?(:topic) @type = args[:type] if args.key?(:type) end |