Class: Google::Apis::AdsenseV2::ReportResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adsense_v2/classes.rb,
lib/google/apis/adsense_v2/representations.rb,
lib/google/apis/adsense_v2/representations.rb

Overview

Result of a generated report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportResult

Returns a new instance of ReportResult.



1118
1119
1120
# File 'lib/google/apis/adsense_v2/classes.rb', line 1118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#averagesGoogle::Apis::AdsenseV2::Row

Row representation. Corresponds to the JSON property averages



1064
1065
1066
# File 'lib/google/apis/adsense_v2/classes.rb', line 1064

def averages
  @averages
end

#end_dateGoogle::Apis::AdsenseV2::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



1076
1077
1078
# File 'lib/google/apis/adsense_v2/classes.rb', line 1076

def end_date
  @end_date
end

#headersArray<Google::Apis::AdsenseV2::Header>

The header information; one for each dimension in the request, followed by one for each metric in the request. Corresponds to the JSON property headers



1082
1083
1084
# File 'lib/google/apis/adsense_v2/classes.rb', line 1082

def headers
  @headers
end

#rowsArray<Google::Apis::AdsenseV2::Row>

The output rows of the report. Each row is a list of cells; one for each dimension in the request, followed by one for each metric in the request. Corresponds to the JSON property rows

Returns:



1088
1089
1090
# File 'lib/google/apis/adsense_v2/classes.rb', line 1088

def rows
  @rows
end

#start_dateGoogle::Apis::AdsenseV2::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



1100
1101
1102
# File 'lib/google/apis/adsense_v2/classes.rb', line 1100

def start_date
  @start_date
end

#total_matched_rowsFixnum

The total number of rows matched by the report request. Corresponds to the JSON property totalMatchedRows

Returns:

  • (Fixnum)


1105
1106
1107
# File 'lib/google/apis/adsense_v2/classes.rb', line 1105

def total_matched_rows
  @total_matched_rows
end

#totalsGoogle::Apis::AdsenseV2::Row

Row representation. Corresponds to the JSON property totals



1110
1111
1112
# File 'lib/google/apis/adsense_v2/classes.rb', line 1110

def totals
  @totals
end

#warningsArray<String>

Any warnings associated with generation of the report. These warnings are always returned in English. Corresponds to the JSON property warnings

Returns:

  • (Array<String>)


1116
1117
1118
# File 'lib/google/apis/adsense_v2/classes.rb', line 1116

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'lib/google/apis/adsense_v2/classes.rb', line 1123

def update!(**args)
  @averages = args[:averages] if args.key?(:averages)
  @end_date = args[:end_date] if args.key?(:end_date)
  @headers = args[:headers] if args.key?(:headers)
  @rows = args[:rows] if args.key?(:rows)
  @start_date = args[:start_date] if args.key?(:start_date)
  @total_matched_rows = args[:total_matched_rows] if args.key?(:total_matched_rows)
  @totals = args[:totals] if args.key?(:totals)
  @warnings = args[:warnings] if args.key?(:warnings)
end