Class: Google::Apis::AdsenseV2::Site
- Inherits:
-
Object
- Object
- Google::Apis::AdsenseV2::Site
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adsense_v2/classes.rb,
lib/google/apis/adsense_v2/representations.rb,
lib/google/apis/adsense_v2/representations.rb
Overview
Representation of a Site.
Instance Attribute Summary collapse
-
#auto_ads_enabled ⇒ Boolean
(also: #auto_ads_enabled?)
Whether auto ads is turned on for the site.
-
#domain ⇒ String
Domain (or subdomain) of the site, e.g.
-
#name ⇒ String
Output only.
-
#reporting_dimension_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Site
constructor
A new instance of Site.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Site
Returns a new instance of Site.
1212 1213 1214 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_ads_enabled ⇒ Boolean Also known as: auto_ads_enabled?
Whether auto ads is turned on for the site.
Corresponds to the JSON property autoAdsEnabled
1187 1188 1189 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1187 def auto_ads_enabled @auto_ads_enabled end |
#domain ⇒ String
Domain (or subdomain) of the site, e.g. "example.com" or "www.example.com".
This is used in the OWNED_SITE_DOMAIN_NAME reporting dimension.
Corresponds to the JSON property domain
1194 1195 1196 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1194 def domain @domain end |
#name ⇒ String
Output only. Resource name of a site. Format: accounts/account/sites/site
Corresponds to the JSON property name
1199 1200 1201 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1199 def name @name end |
#reporting_dimension_id ⇒ String
Output only. Unique ID of the site as used in the OWNED_SITE_ID reporting
dimension.
Corresponds to the JSON property reportingDimensionId
1205 1206 1207 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1205 def reporting_dimension_id @reporting_dimension_id end |
#state ⇒ String
Output only. State of a site.
Corresponds to the JSON property state
1210 1211 1212 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1210 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/google/apis/adsense_v2/classes.rb', line 1217 def update!(**args) @auto_ads_enabled = args[:auto_ads_enabled] if args.key?(:auto_ads_enabled) @domain = args[:domain] if args.key?(:domain) @name = args[:name] if args.key?(:name) @reporting_dimension_id = args[:reporting_dimension_id] if args.key?(:reporting_dimension_id) @state = args[:state] if args.key?(:state) end |